==> jc-1.4.0.tar.gz: javax/net/ssl/HandshakeCompletedEvent.h <==
// public class javax.net.ssl.HandshakeCompletedEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 93ed90414a557ca1 javax_net_ssl_HandshakeCompletedEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_net_ssl_HandshakeCompletedEvent_H_
#define _JC_javax_net_ssl_HandshakeCompletedEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_net_ssl_SSLSession$object;
struct _jc_javax_net_ssl_SSLSocket$object;

// Typedefs
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$sub_refs	_jc_javax_net_ssl_HandshakeCompletedEvent$sub_refs;
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$sub_nonrefs	_jc_javax_net_ssl_HandshakeCompletedEvent$sub_nonrefs;
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$refs	_jc_javax_net_ssl_HandshakeCompletedEvent$refs;
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$nonrefs	_jc_javax_net_ssl_HandshakeCompletedEvent$nonrefs;
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$object	_jc_javax_net_ssl_HandshakeCompletedEvent$object;

typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$fields_struct	_jc_javax_net_ssl_HandshakeCompletedEvent$fields_struct;
typedef const struct _jc_javax_net_ssl_HandshakeCompletedEvent$vmethods	_jc_javax_net_ssl_HandshakeCompletedEvent$vmethods;
typedef const struct _jc_javax_net_ssl_HandshakeCompletedEvent$vtable	_jc_javax_net_ssl_HandshakeCompletedEvent$vtable;
typedef const struct _jc_javax_net_ssl_HandshakeCompletedEvent$vtype	_jc_javax_net_ssl_HandshakeCompletedEvent$vtype;

// Class fields structure
struct _jc_javax_net_ssl_HandshakeCompletedEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_net_ssl_HandshakeCompletedEvent$fields_struct _jc_javax_net_ssl_HandshakeCompletedEvent$class_fields;

// Constructors
extern void _jc_javax_net_ssl_HandshakeCompletedEvent$method$_init$cf0a47b4c7a6235c(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *, struct _jc_javax_net_ssl_SSLSocket$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getCipherSuite$1373af5280c43dcf(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
extern _jc_object_array *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getLocalCertificates$ac9a619754351a58(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
extern _jc_object_array *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getPeerCertificateChain$7e0f800e3e10846c(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
extern _jc_object_array *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getPeerCertificates$de45a7abfa722b3b(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
extern struct _jc_object *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getSession$053c67d6c8c9d2b9(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
extern struct _jc_javax_net_ssl_SSLSocket$object *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getSocket$14b81cb5b17e6d42(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getCipherSuite$1373af5280c43dcf;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getLocalCertificates$ac9a619754351a58;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getPeerCertificateChain$7e0f800e3e10846c;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getPeerCertificates$de45a7abfa722b3b;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getSession$053c67d6c8c9d2b9;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getSocket$14b81cb5b17e6d42;

// Virtual methods structure
struct _jc_javax_net_ssl_HandshakeCompletedEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getCipherSuite$1373af5280c43dcf)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
	_jc_object_array	*(*getLocalCertificates$ac9a619754351a58)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
	_jc_object_array	*(*getPeerCertificateChain$7e0f800e3e10846c)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
	_jc_object_array	*(*getPeerCertificates$de45a7abfa722b3b)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
	struct _jc_object	*(*getSession$053c67d6c8c9d2b9)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
	struct _jc_javax_net_ssl_SSLSocket$object	*(*getSocket$14b81cb5b17e6d42)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *);
};

// Vtable
struct _jc_javax_net_ssl_HandshakeCompletedEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_net_ssl_HandshakeCompletedEvent$vmethods	javax_net_ssl_HandshakeCompletedEvent;
};

// Vtype
struct _jc_javax_net_ssl_HandshakeCompletedEvent$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_HandshakeCompletedEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_HandshakeCompletedEvent$sub_refs {
	struct _jc_object	*session;
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_HandshakeCompletedEvent$refs {
    _jc_javax_net_ssl_HandshakeCompletedEvent$sub_refs	javax_net_ssl_HandshakeCompletedEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_HandshakeCompletedEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_HandshakeCompletedEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_net_ssl_HandshakeCompletedEvent$sub_nonrefs	javax_net_ssl_HandshakeCompletedEvent;
};

// Object instance structure
struct _jc_javax_net_ssl_HandshakeCompletedEvent$object {
	_jc_javax_net_ssl_HandshakeCompletedEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_HandshakeCompletedEvent$vtype	*vtype;
	_jc_javax_net_ssl_HandshakeCompletedEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_HandshakeCompletedEvent$vtype _jc_javax_net_ssl_HandshakeCompletedEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_HandshakeCompletedEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_HandshakeCompletedEvent$class_object;

#endif	/* _JC_javax_net_ssl_HandshakeCompletedEvent_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/HandshakeCompletedEvent.h <==
// public class javax.net.ssl.HandshakeCompletedEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 93ed90414a557ca1 javax_net_ssl_HandshakeCompletedEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_net_ssl_HandshakeCompletedEvent_H_
#define _JC_javax_net_ssl_HandshakeCompletedEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_net_ssl_SSLSession$object;
struct _jc_javax_net_ssl_SSLSocket$object;

// Typedefs
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$sub_refs	_jc_javax_net_ssl_HandshakeCompletedEvent$sub_refs;
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$sub_nonrefs	_jc_javax_net_ssl_HandshakeCompletedEvent$sub_nonrefs;
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$refs	_jc_javax_net_ssl_HandshakeCompletedEvent$refs;
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$nonrefs	_jc_javax_net_ssl_HandshakeCompletedEvent$nonrefs;
typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$object	_jc_javax_net_ssl_HandshakeCompletedEvent$object;

typedef struct _jc_javax_net_ssl_HandshakeCompletedEvent$fields_struct	_jc_javax_net_ssl_HandshakeCompletedEvent$fields_struct;
typedef const struct _jc_javax_net_ssl_HandshakeCompletedEvent$vmethods	_jc_javax_net_ssl_HandshakeCompletedEvent$vmethods;
typedef const struct _jc_javax_net_ssl_HandshakeCompletedEvent$vtable	_jc_javax_net_ssl_HandshakeCompletedEvent$vtable;
typedef const struct _jc_javax_net_ssl_HandshakeCompletedEvent$vtype	_jc_javax_net_ssl_HandshakeCompletedEvent$vtype;

// Class fields structure
struct _jc_javax_net_ssl_HandshakeCompletedEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_net_ssl_HandshakeCompletedEvent$fields_struct _jc_javax_net_ssl_HandshakeCompletedEvent$class_fields;

// Constructors
extern void _jc_javax_net_ssl_HandshakeCompletedEvent$method$_init$cf0a47b4c7a6235c(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *, struct _jc_javax_net_ssl_SSLSocket$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getCipherSuite$1373af5280c43dcf(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getLocalCertificates$ac9a619754351a58(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getPeerCertificateChain$7e0f800e3e10846c(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getPeerCertificates$de45a7abfa722b3b(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getSession$053c67d6c8c9d2b9(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_net_ssl_SSLSocket$object *_jc_javax_net_ssl_HandshakeCompletedEvent$method$getSocket$14b81cb5b17e6d42(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getCipherSuite$1373af5280c43dcf;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getLocalCertificates$ac9a619754351a58;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getPeerCertificateChain$7e0f800e3e10846c;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getPeerCertificates$de45a7abfa722b3b;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getSession$053c67d6c8c9d2b9;
extern _jc_method _jc_javax_net_ssl_HandshakeCompletedEvent$method_info$getSocket$14b81cb5b17e6d42;

// Virtual methods structure
struct _jc_javax_net_ssl_HandshakeCompletedEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getCipherSuite$1373af5280c43dcf)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getLocalCertificates$ac9a619754351a58)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getPeerCertificateChain$7e0f800e3e10846c)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getPeerCertificates$de45a7abfa722b3b)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getSession$053c67d6c8c9d2b9)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
	struct _jc_javax_net_ssl_SSLSocket$object	*(*getSocket$14b81cb5b17e6d42)(_jc_env *, struct _jc_javax_net_ssl_HandshakeCompletedEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_HandshakeCompletedEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_net_ssl_HandshakeCompletedEvent$vmethods	javax_net_ssl_HandshakeCompletedEvent;
};

// Vtype
struct _jc_javax_net_ssl_HandshakeCompletedEvent$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_HandshakeCompletedEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_HandshakeCompletedEvent$sub_refs {
	struct _jc_object	*session;
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_HandshakeCompletedEvent$refs {
    _jc_javax_net_ssl_HandshakeCompletedEvent$sub_refs	javax_net_ssl_HandshakeCompletedEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_HandshakeCompletedEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_HandshakeCompletedEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_net_ssl_HandshakeCompletedEvent$sub_nonrefs	javax_net_ssl_HandshakeCompletedEvent;
};

// Object instance structure
struct _jc_javax_net_ssl_HandshakeCompletedEvent$object {
	_jc_javax_net_ssl_HandshakeCompletedEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_HandshakeCompletedEvent$vtype	*vtype;
	_jc_javax_net_ssl_HandshakeCompletedEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_HandshakeCompletedEvent$vtype _jc_javax_net_ssl_HandshakeCompletedEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_HandshakeCompletedEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_HandshakeCompletedEvent$class_object;

#endif	/* _JC_javax_net_ssl_HandshakeCompletedEvent_H_ */
